/*==============================================================================
 Fractal XDoclet Plugin - Copyright (C) 2002-2006 INRIA Futurs / LIFL
 Fractal Component Model (contact: fractal@objectweb.org)

 This library is free software; you can redistribute it and/or modify it under 
 the terms of the GNU Lesser General Public License as published by the Free 
 Software Foundation; either version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful, but WITHOUT ANY 
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License along 
 with this library; if not, write to the Free Software Foundation, Inc., 
 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

 Initial developer(s): Romain Rouvoy (romain.rouvoy@lifl.fr)
 Contributor(s): .
 --------------------------------------------------------------------------------
 $Id: CompositeDefinitionPlugin.java,v 1.2 2006/08/30 15:18:22 rouvoy Exp $
 ==============================================================================*/
package org.objectweb.fractal.fraclet;

import java.util.Iterator;
import java.util.StringTokenizer;

import org.generama.JellyTemplateEngine;
import org.generama.QDoxCapableMetadataProvider;
import org.generama.WriterMapper;

import com.thoughtworks.qdox.model.JavaClass;

/**
 * XDoclet plugin applied in conjunction with the FractalAdlPlugin.jelly
 * template to generate primitive component descriptor file.
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version $Revision: 1.2 $
 */
public class CompositeDefinitionPlugin extends PrimitiveDefinitionPlugin {
    protected static final String ASSEMBLY_SUFFIX = "Composite";

    /**
     * Composite definition generator for abstract composite.
     * @param jelly the jelly XML template engine.
     * @param qdox the qdox java model provider.
     * @param writer the file writer mapper.
     */
    public CompositeDefinitionPlugin(JellyTemplateEngine jelly,
            QDoxCapableMetadataProvider qdox, WriterMapper writer) {
        super(jelly, qdox, writer);
        setFilereplace("$1" + ASSEMBLY_SUFFIX + ".fractal");
    }

    /**
     * param cls the java class source file parsed.
     * @return true if a FractalADL file should be generated.
     */
    public boolean shouldGenerate(final Object cls) {
        return super.shouldGenerate(cls) && hasBindings((JavaClass) cls, true);
    }

    /* (non-Javadoc)
     * @see org.objectweb.fractal.fraclet.PrimitiveDefinitionPlugin#extendsElement(com.thoughtworks.qdox.model.JavaClass)
     */
    protected String extendsElement(final JavaClass cls) {
        if (cls != null && isComponent(cls))
            return DEFINITION_SEPARATOR+cls.getFullyQualifiedName()+ASSEMBLY_SUFFIX;
        return super.extendsElement(cls);
    }
    
    /**
     * Provides the instance of the class element named name.
     * @param name the name of the class to find.
     * @return the associated Java model element (null if not found).
     */
    public JavaClass interfaceClass(final String name) {
        for (Iterator i = this.getMetadata().iterator(); i.hasNext();) {
            JavaClass cls = (JavaClass) i.next();
            if (name.equals(cls.getFullyQualifiedName()))
                return cls;
        }
        return null;
    }

    /**
     * Provides the list of parameters of a component.
     * @param cls the component considered.
     * @return the parameters of the component.
     */
    public String parameters(final JavaClass cls) {
        String args = argumentsDefinition(cls);
        if (args == null)
            return "";
        StringBuffer buffer = new StringBuffer();
        for (StringTokenizer tokens = new StringTokenizer(args, ","); tokens
                .hasMoreTokens();) {
            buffer.append(DEFINITION_SEPARATOR + "${" + tokens.nextToken()
                    + "}");
        }
        return "(" + buffer.substring(DEFINITION_SEPARATOR.length()) + ")";
    }
}